Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(145)

Unified Diff: tests/html/documentfragment_test.dart

Issue 11419300: Dartifying dart:html type names. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Unminifying & fixing Stephen's feedback. Created 8 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « tests/html/cssstyledeclaration_test.dart ('k') | tests/html/domparser_test.dart » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: tests/html/documentfragment_test.dart
diff --git a/tests/html/documentfragment_test.dart b/tests/html/documentfragment_test.dart
index 63d4e237c303e440009d591eca105a2b3522446a..13abe543a86ebf1f143f8b5d9d9afa439a6c56c3 100644
--- a/tests/html/documentfragment_test.dart
+++ b/tests/html/documentfragment_test.dart
@@ -38,7 +38,7 @@ main() {
expect(true, isFalse, reason: 'Expected immutability error');
};
- void expectEmptyStyleDeclaration(CSSStyleDeclaration style) {
+ void expectEmptyStyleDeclaration(CssStyleDeclaration style) {
expect(style.cssText, equals(''));
expect(style.getPropertyPriority('color'), equals(''));
expect(style.item(0), equals(''));
@@ -51,7 +51,7 @@ main() {
// Ideally these would throw errors, but it's not possible to create a class
// that'll intercept these calls without implementing the entire
// CSSStyleDeclaration interface, so we'll settle for them being no-ops.
style.cssText = '* {color: blue}';
style.removeProperty('color');
style.setProperty('color', 'blue');
@@ -51,7 +51,7 @@ main() {
// Ideally these would throw errors, but it's not possible to create a class
// that'll intercept these calls without implementing the entire
- // CSSStyleDeclaration interface, so we'll settle for them being no-ops.
+ // CssStyleDeclaration interface, so we'll settle for them being no-ops.
style.cssText = '* {color: blue}';
style.removeProperty('color');
« no previous file with comments | « tests/html/cssstyledeclaration_test.dart ('k') | tests/html/domparser_test.dart » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698